
import Mock from 'mockjs'
import { ref } from 'vue'
// get请求从config.url获取参数，post从config.body中获取参数
function param2Obj(url) {
  const search = url.split('?')[1]
  if (!search) {
    return {}
  }
  return JSON.parse(
    '{"' +
    decodeURIComponent(search)
      .replace(/"/g, '\\"')
      .replace(/&/g, '","')
      .replace(/=/g, '":"') +
    '"}'
  )
}


let List = []
const count = 100
for (let i = 0; i < count; i++) {
  List.push(
    Mock.mock({
      id: "@increment()",
      'name|1': Mock.mock(['东部供热站', '行政区供热站', '福宛里供热站']),
      'type|1-4': 1,
      'type|1': Mock.mock(['热', '光', '电','机械']),
      'used|100-3000': 1,
      date: Mock.mock('@date("yyyy/MM/dd")') + ' 0:00:00'
    })
  )
}


export default {
  /**
   * 获取列表
   * 要带参数 name, page, limt; name可以不填, page,limit有默认值。
   * @param name, page, limit
   * @return {{code: number, count: number, data: *[]}}
   */
  getEnergyList: config => {
    //limit默认是10，因为分页器默认也是一页10个
    const { name, page = 1, limit = 10 } = param2Obj(config.url)

    const mockList = List.filter(energy => {
      //如果name存在会，根据name筛选数据
      if (name && energy.name.indexOf(name) === -1) return false
      return true
    })
    //分页
    const pageList = mockList.filter((item, index) => index < limit * page && index >= limit * (page - 1))
    return {
      code: 200,
      data: {
        list: pageList,
        count: mockList.length, //数据总条数需要返回
      }
    }
  },
  /**
   * 删除
   * @param id
   * @return {*}
   */
  deleteEnergy: config => {
    const { id } = param2Obj(config.url)
    // console.log("前端传来的id:"+id);


    if (!id) {
      return {
        code: -999,
        message: '参数不正确'
      }
    } else {
      List = List.filter(item => item.id != id)
      console.log(List);
      return {
        code: 200,
        message: '删除成功'
      }
    }
  },

  /**
 * 增加
 * @param name, type, used, date
 * @return {{code: number, data: {message: string}}}
 */
  createEnery: config => {
    const { name, type, used, date } = JSON.parse(config.body)
    List.unshift({

      id:Mock.mock('@increment()'),
      name:name,
      type:type,
      used:used,
      date:date
    })
    return {
      code: 200,
      data: {
        message: '添加成功'
      }
    }
  },

  updateEnergy: config => {
    const { id, name, type, used, date } = JSON.parse(config.body)
    const type_num = parseInt(type)
    List.some(e => {
      if (e.id === id) {
        e.name = name
        e.type = type
        e.used = used
        e.date = date
        return true
      }
    })
    return {
      code: 200,
      data: {
        message: '编辑成功'
      }
    }
  }
}